import {
    Tooltip,
    TooltipContent,
    TooltipProvider,
    TooltipTrigger,
} from "@/components/ui/tooltip";

export interface HintProps {
    label: string;
    children: React.ReactNode;
    side?: "top" | "bottom" | "left" | "right";
    align?: "start" | "center" | "end";
    sideOffset?: number;
    alightOffset?: number;
};

export const Hint = ({
    label,
    children,
    side,
    align,
    sideOffset,
    alightOffset,
}: HintProps) => {
    return (
        <TooltipProvider>
            <Tooltip delayDuration={100}>
                <TooltipTrigger asChild>
                {/* asChild는 기능은 그대로 children 태그를 대신 렌더링.*/}
                    {children}
                </TooltipTrigger>
                <TooltipContent
                    className="text-white bg-slate-800 border-slate-800"
                    side={side}
                    align={align}
                    sideOffset={sideOffset}
                    alignOffset={alightOffset}
                >
                    <p className="font-semibold capitalize">
                        {label}
                    </p>
                </TooltipContent>
            </Tooltip>
        </TooltipProvider>

    )
};