import { fabric } from "fabric";
import { useCallback, useState } from "react";
import { useAutoResize } from "./use-auto-resize";


interface UseEditorProps {
    initialCanvas: fabric.Canvas;
    initialContainer: HTMLDivElement;
}
export const useEditor = () => {
    const[canvas, setCanvas] = useState<fabric.Canvas | null>(null);
    const[container, setContatiner] = useState<HTMLDivElement | null>(null);

    useAutoResize({
        canvas,
        container,
    });
    
    const init = useCallback(
        ({initialCanvas,initialContainer}: UseEditorProps) => {
        fabric.Object.prototype.set({
            cornerColor: "#FFF",
            cornerStyle: "circle",
            borderColor: "#3b82f6",
            borderScaleFactor: 1.5,
            transparentCorners: false,
            borderOpacityWhenMoving: 1,
            cornerStrokeColor: "#3b82f6",
        }
    )

        const initialWorkspace = new fabric.Rect({
            width: 900,
            height: 1200,
            name: "clip",
            fill: "white",
            selectable: false,
            hasControls: false,
            shadow: new fabric.Shadow({
                color: "rgba(0,0,0,0.8)",
                blur: 5
            })
        })

        initialCanvas.setWidth(initialContainer.offsetWidth); 
        initialCanvas.setHeight(initialContainer.offsetHeight);

        initialCanvas.add(initialWorkspace);
        initialCanvas.centerObject(initialWorkspace);
        initialCanvas.clipPath = initialWorkspace; // clip the canvas to the workspace

        setCanvas(initialCanvas);
        setContatiner(initialContainer);

        const test = new fabric.Rect({
            height: 100,
            width: 100,
            fill: "black",
        });
        
        initialCanvas.add(test);
        initialCanvas.centerObject(test);
    },
    []);

    return { init };
};